@@ -90,8 +90,19 @@ type Root struct {
 	FollowAll bool
 	// skipDraw is set to true when the mouse cursor just moves (no event occurs).
 	skipDraw bool
+	// clickState is the state of mouse click.
+	clickState ClickState
 }
 
+// MouseSelectState represents the state of mouse selection.
+type MouseSelectState int
+
+const (
+	SelectNone   MouseSelectState = iota // no selection
+	SelectActive                         // selecting
+	SelectCopied                         // selection copied
+)
+
 // SCR contains the screen information.
 type SCR struct {
 	// lines is the lines of the screen.
@@ -107,6 +118,9 @@ type SCR struct {
 	startX int
 	// startY is the start position of y.
 	startY int
+	// statusLineHeight is the height of the status line.
+	statusLineHeight int
+
 	// rulerHeight is the height of the ruler.
 	rulerHeight int
 	// HeaderLN is the number of header lines.
@@ -128,11 +142,15 @@ type SCR struct {
 	x2 int
 	y2 int
 	// mouseSelect is a flag with mouse selection.
-	mouseSelect bool
+	mouseSelect MouseSelectState
 	// mousePressed is a flag when the mouse selection button is pressed.
 	mousePressed bool
 	// mouseRectangle is a flag for rectangle selection.
 	mouseRectangle bool
+	// hasAnchorPoint is a flag whether anchor point exists.
+	hasAnchorPoint bool
+	// forceDisplaySync forces synchronous display.
+	forceDisplaySync bool
 }
 
 // LineNumber is Number of logical lines and number of wrapping lines on the screen.
@@ -215,6 +233,8 @@ type RunTimeSettings struct {
 	HScrollWidth string
 	// HScrollWidthNum is the horizontal scroll width.
 	HScrollWidthNum int
+	// VScrollLines is the number of lines to scroll with the mouse wheel.
+	VScrollLines int
 	// RulerType is the ruler type (0: none, 1: relative, 2: absolute).
 	RulerType RulerType
 	// AlternateRows alternately style rows.
@@ -243,7 +263,11 @@ type RunTimeSettings struct {
 	SectionHeader bool
 	// HideOtherSection is whether to hide other sections.
 	HideOtherSection bool
+	// StatusLine is whether to hide the status line.
+	StatusLine bool
 
+	// PromptConfig is the prompt configuration.
+	OVPromptConfig
 	// Style is the style of the document.
 	Style Style
 }
@@ -285,6 +309,16 @@ type Style struct {
 	// VerticalHeaderBorder is the style that applies to the boundary character of the vertical header.
 	// The boundary character of the vertical header refers to the visual separator that delineates the vertical header from the rest of the content.
 	VerticalHeaderBorder OVStyle
+	// LeftStatus is the style that applies to the left status line.
+	LeftStatus OVStyle
+	// RightStatus is the style that applies to the right status line.
+	RightStatus OVStyle
+	// SelectActive is the style that applies to the text being selected (during mouse drag).
+	SelectActive OVStyle
+	// SelectCopied is the style that applies to the text that has been copied to clipboard.
+	SelectCopied OVStyle
+	// PauseLine is the style that applies to the line where follow mode is paused.
+	PauseLine OVStyle
 }
 
 var (
@@ -337,13 +371,13 @@ const (
 
 var (
 	// ErrOutOfRange indicates that value is out of range.
-	ErrOutOfRange = errors.New("out of range")
+	ErrOutOfRange = errors.New("value out of range")
 	// ErrNotInMemory indicates that value is not in memory.
-	ErrNotInMemory = errors.New("not in memory")
+	ErrNotInMemory = errors.New("value not in memory")
 	// ErrFatalCache indicates that the cache value had a fatal error.
-	ErrFatalCache = errors.New("fatal error in cache value")
+	ErrFatalCache = errors.New("fatal cache error")
 	// ErrMissingFile indicates that the file does not exist.
-	ErrMissingFile = errors.New("missing filename")
+	ErrMissingFile = errors.New("missing file")
 	// ErrIsDirectory indicates that specify a directory instead of a file.
 	ErrIsDirectory = errors.New("is a directory")
 	// ErrNotFound indicates not found.
@@ -355,52 +389,65 @@ var (
 	// ErrInvalidNumber indicates an invalid number.
 	ErrInvalidNumber = errors.New("invalid number")
 	// ErrFailedKeyBind indicates keybinding failed.
-	ErrFailedKeyBind = errors.New("failed to set keybind")
+	ErrFailedKeyBind = errors.New("failed to set key bindings")
 	// ErrSignalCatch indicates that the signal has been caught.
-	ErrSignalCatch = errors.New("signal catch")
+	ErrSignalCatch = errors.New("signal caught")
 	// ErrAlreadyClose indicates that it is already closed.
 	ErrAlreadyClose = errors.New("already closed")
 	// ErrCannotClose indicates that it cannot be closed.
-	ErrCannotClose = errors.New("cannot close")
+	ErrCannotClose = errors.New("cannot be closed")
 	// ErrRequestClose indicates that the request is to close.
-	ErrRequestClose = errors.New("request close")
+	ErrRequestClose = errors.New("close requested")
 	// ErrNoColumn indicates that cursor specified a nonexistent column.
-	ErrNoColumn = errors.New("no column")
+	ErrNoColumn = errors.New("column not found")
 	// ErrNoDelimiter indicates that the line containing the delimiter could not be found.
-	ErrNoDelimiter = errors.New("no delimiter")
+	ErrNoDelimiter = errors.New("delimiter not found")
 	// ErrNoMoreSection indicates that the section could not be found.
-	ErrNoMoreSection = errors.New("no more section")
+	ErrNoMoreSection = errors.New("no more sections")
 	// ErrOverScreen indicates that the specified screen is out of range.
-	ErrOverScreen = errors.New("over screen")
+	ErrOverScreen = errors.New("screen position out of range")
 	// ErrOutOfChunk indicates that the specified Chunk is out of range.
-	ErrOutOfChunk = errors.New("out of chunk")
+	ErrOutOfChunk = errors.New("chunk out of range")
 	// ErrNotLoaded indicates that it cannot be loaded.
 	ErrNotLoaded = errors.New("not loaded")
 	// ErrEOFreached indicates that EOF has been reached.
 	ErrEOFreached = errors.New("EOF reached")
 	// ErrPreventReload indicates that reload is prevented.
-	ErrPreventReload = errors.New("prevent reload")
+	ErrPreventReload = errors.New("reload prevented")
 	// ErrOverChunkLimit indicates that the chunk limit has been exceeded.
-	ErrOverChunkLimit = errors.New("over chunk limit")
+	ErrOverChunkLimit = errors.New("chunk limit exceeded")
 	// ErrAlreadyLoaded indicates that the chunk already loaded.
 	ErrAlreadyLoaded = errors.New("chunk already loaded")
 	// ErrEvictedMemory indicates that it has been evicted from memory.
-	ErrEvictedMemory = errors.New("evicted memory")
+	ErrEvictedMemory = errors.New("evicted from memory")
 	// ErrNotAlignMode indicates that it is not an align mode.
-	ErrNotAlignMode = errors.New("not an align mode")
+	ErrNotAlignMode = errors.New("not in align mode")
 	// ErrNoColumnSelected indicates that no column is selected.
 	ErrNoColumnSelected = errors.New("no column selected")
 	// ErrInvalidSGR indicates that the SGR is invalid.
 	ErrInvalidSGR = errors.New("invalid SGR")
 	// ErrNotSupport indicates that it is not supported.
-	ErrNotSupport = errors.New("not support")
+	ErrNotSupport = errors.New("not supported")
 	// ErrInvalidDocumentNum indicates that the document number is invalid.
 	ErrInvalidDocumentNum = errors.New("invalid document number")
+	// ErrInvalidModeName indicates that the specified view mode was not found.
+	ErrInvalidModeName = errors.New("view mode not found")
+	// ErrInvalidRGBColor indicates that the RGB color is invalid.
+	ErrInvalidRGBColor = errors.New("invalid RGB color")
+	// ErrInvalidKey indicates that the key format is invalid.
+	ErrInvalidKey = errors.New("invalid key format")
 )
 
 // This is a function of tcell.NewScreen but can be replaced with mock.
 var tcellNewScreen = tcell.NewScreen
 
+// SetTcellNewScreen sets the function to create a new tcell screen.
+// This is used for testing purposes to replace the tcell.NewScreen function.
+// It allows for mocking the screen creation in tests.
+func SetTcellNewScreen(f func() (tcell.Screen, error)) {
+	tcellNewScreen = f
+}
+
 // NewOviewer return the structure of oviewer.
 // NewOviewer requires one or more documents.
 func NewOviewer(docs ...*Document) (*Root, error) {
@@ -442,7 +489,10 @@ func NewRunTimeSettings() RunTimeSettings {
 		TabWidth:       8,
 		MarkStyleWidth: 1,
 		Converter:      convEscaped,
+		OVPromptConfig: NewOVPromptConfig(),
 		Style:          NewStyle(),
+		StatusLine:     true,
+		VScrollLines:   2,
 	}
 }
 
@@ -500,6 +550,15 @@ func NewStyle() Style {
 			Foreground: "#CCCCCC",
 			Bold:       true,
 		},
+		SelectActive: OVStyle{
+			Reverse: true,
+		},
+		SelectCopied: OVStyle{
+			Background: "slategrey",
+		},
+		PauseLine: OVStyle{
+			Background: "#663333",
+		},
 	}
 }
 
@@ -589,13 +648,15 @@ func openFiles(fileNames []string) (*Root, error) {
 		}
 	}
 
-	return root, err
+	return root, nil
 }
 
 // SetConfig sets config.
 func (root *Root) SetConfig(config Config) {
 	// Old Style* settings are loaded with lower priority.
 	root.settings = setOldStyle(root.settings, config)
+	// Old Prompt settings are loaded with lower priority.
+	root.settings = setOldPrompt(root.settings, config)
 	// General settings.
 	root.settings = updateRunTimeSettings(root.settings, config.General)
 
@@ -731,12 +792,6 @@ func (root *Root) Run() error {
 		return err
 	}
 
-	// Quit if fits on screen.
-	if root.Config.QuitSmall && root.DocumentLen() == 1 && root.docSmall() {
-		root.Config.IsWriteOnExit = true
-		return nil
-	}
-
 	sigs := make(chan os.Signal, 1)
 	signal.Notify(sigs, os.Interrupt, syscall.SIGTERM, syscall.SIGHUP, syscall.SIGINT)
 	sigSuspend := registerSIGTSTP()
@@ -783,14 +838,19 @@ func (root *Root) prepareRun(ctx context.Context) error {
 	}
 
 	if root.Config.ShrinkChar != "" {
-		Shrink = []rune(root.Config.ShrinkChar)[0]
+		Shrink = root.Config.ShrinkChar
+		SetShrinkContent(Shrink)
 	}
-	SetShrinkContent(Shrink)
 
 	root.setCaption()
 
 	root.setViewModeConfig()
 	root.prepareAllDocuments()
+	// follow mode or follow all disables quit if the output fits on one screen.
+	if root.Doc.FollowMode || root.FollowAll {
+		root.Config.QuitSmall = false
+		root.Config.QuitSmallFilter = false
+	}
 	// Quit by filter result. This is evaluated lazily.
 	if root.Config.QuitSmallFilter {
 		root.quitSmallCountDown = QuitSmallCountDown
@@ -827,6 +887,7 @@ func (root *Root) setViewModeConfig() {
 func (root *Root) prepareAllDocuments() {
 	for n, doc := range root.DocList {
 		doc.RunTimeSettings = root.settings
+		doc.RunTimeSettings = updateRunTimeSettings(doc.RunTimeSettings, doc.General)
 		doc.regexpCompile()
 
 		if doc.FollowName {
@@ -845,8 +906,9 @@ func (root *Root) prepareAllDocuments() {
 		}
 		log.Printf("open [%d]%s%s\n", n, doc.FileName, w)
 	}
-	root.helpDoc.Style = root.settings.Style
-	root.logDoc.Style = root.settings.Style
+
+	root.helpDoc.RunTimeSettings = updateRunTimeSettings(root.helpDoc.RunTimeSettings, root.Config.HelpDoc)
+	root.logDoc.RunTimeSettings = updateRunTimeSettings(root.logDoc.RunTimeSettings, root.Config.LogDoc)
 }
 
 // Close closes the oviewer.
@@ -955,6 +1017,24 @@ func setOldStyle(src RunTimeSettings, config Config) RunTimeSettings {
 	return src
 }
 
+// setOldPrompt applies deprecated prompt settings for backward compatibility.
+//
+// Deprecated: This function is planned to be removed in future versions.
+func setOldPrompt(src RunTimeSettings, config Config) RunTimeSettings {
+	prompt := config.Prompt
+	// Old PromptConfig settings are loaded with lower priority.
+	if prompt.Normal.ShowFilename != nil {
+		src.OVPromptConfig.Normal.ShowFilename = *prompt.Normal.ShowFilename
+	}
+	if prompt.Normal.InvertColor != nil {
+		src.OVPromptConfig.Normal.InvertColor = *prompt.Normal.InvertColor
+	}
+	if prompt.Normal.ProcessOfCount != nil {
+		src.OVPromptConfig.Normal.ProcessOfCount = *prompt.Normal.ProcessOfCount
+	}
+	return src
+}
+
 // updateRunTimeSettings updates the RunTimeSettings.
 func updateRunTimeSettings(src RunTimeSettings, dst General) RunTimeSettings {
 	if dst.TabWidth != nil {
@@ -990,6 +1070,9 @@ func updateRunTimeSettings(src RunTimeSettings, dst General) RunTimeSettings {
 	if dst.HScrollWidthNum != nil {
 		src.HScrollWidthNum = *dst.HScrollWidthNum
 	}
+	if dst.VScrollLines != nil {
+		src.VScrollLines = *dst.VScrollLines
+	}
 	if dst.RulerType != nil {
 		src.RulerType = *dst.RulerType
 	}
@@ -1032,6 +1115,9 @@ func updateRunTimeSettings(src RunTimeSettings, dst General) RunTimeSettings {
 	if dst.HideOtherSection != nil {
 		src.HideOtherSection = *dst.HideOtherSection
 	}
+	if dst.StatusLine != nil {
+		src.StatusLine = *dst.StatusLine
+	}
 	if dst.ColumnDelimiter != nil {
 		src.ColumnDelimiter = *dst.ColumnDelimiter
 	}
@@ -1056,10 +1142,31 @@ func updateRunTimeSettings(src RunTimeSettings, dst General) RunTimeSettings {
 	if dst.Raw != nil && *dst.Raw {
 		src.Converter = convRaw
 	}
+	src.OVPromptConfig = updatePromptConfig(src.OVPromptConfig, dst.Prompt)
 	src.Style = updateRuntimeStyle(src.Style, dst.Style)
 	return src
 }
 
+// updatePromptConfig updates the prompt configuration.
+func updatePromptConfig(src OVPromptConfig, dst PromptConfig) OVPromptConfig {
+	if dst.Normal.InvertColor != nil {
+		src.Normal.InvertColor = *dst.Normal.InvertColor
+	}
+	if dst.Normal.ShowFilename != nil {
+		src.Normal.ShowFilename = *dst.Normal.ShowFilename
+	}
+	if dst.Normal.ProcessOfCount != nil {
+		src.Normal.ProcessOfCount = *dst.Normal.ProcessOfCount
+	}
+	if dst.Normal.CursorType != nil {
+		src.Normal.CursorType = *dst.Normal.CursorType
+	}
+	if dst.Input.CursorType != nil {
+		src.Input.CursorType = *dst.Input.CursorType
+	}
+	return src
+}
+
 // updateRuntimeStyle updates the style.
 func updateRuntimeStyle(src Style, dst StyleConfig) Style {
 	if dst.ColumnRainbow != nil {
@@ -1110,6 +1217,21 @@ func updateRuntimeStyle(src Style, dst StyleConfig) Style {
 	if dst.VerticalHeaderBorder != nil {
 		src.VerticalHeaderBorder = *dst.VerticalHeaderBorder
 	}
+	if dst.LeftStatus != nil {
+		src.LeftStatus = *dst.LeftStatus
+	}
+	if dst.RightStatus != nil {
+		src.RightStatus = *dst.RightStatus
+	}
+	if dst.SelectActive != nil {
+		src.SelectActive = *dst.SelectActive
+	}
+	if dst.SelectCopied != nil {
+		src.SelectCopied = *dst.SelectCopied
+	}
+	if dst.PauseLine != nil {
+		src.PauseLine = *dst.PauseLine
+	}
 	return src
 }
 
@@ -1120,6 +1242,7 @@ func (root *Root) docSmall() bool {
 	if !m.BufEOF() {
 		return false
 	}
+	screenHeight := root.scr.vHeight - root.scr.statusLineHeight
 	height := 0
 	for y := range m.BufEndNum() {
 		lc, err := m.contents(y)
@@ -1128,7 +1251,7 @@ func (root *Root) docSmall() bool {
 			continue
 		}
 		height += 1 + (len(lc) / root.scr.vWidth)
-		if height > root.scr.vHeight {
+		if height > screenHeight {
 			return false
 		}
 	}
@@ -1176,7 +1299,7 @@ func (root *Root) writeCurrentScreen(output io.Writer) {
 			log.Println(err)
 			return
 		}
-		strs = tcellansi.ScreenContentToStrings(root.Screen, 0, root.Doc.width, 0, height-1)
+		strs = tcellansi.ScreenContentToStrings(root.Screen, 0, root.Doc.width, 0, height)
 		strs = tcellansi.TrimRightSpaces(strs)
 	}
 	for _, str := range strs {
@@ -1200,7 +1323,7 @@ func (root *Root) dummyScreen() (int, error) {
 		if root.Config.AfterWriteOriginal != 0 {
 			end = root.Doc.topLN + root.Config.AfterWriteOriginal
 		}
-		height = end - root.Doc.topLN
+		height = max(end-root.Doc.topLN, 0)
 	}
 	root.Screen.SetSize(root.scr.vWidth, height)
 	if root.Pattern != "" {
@@ -1210,13 +1333,13 @@ func (root *Root) dummyScreen() (int, error) {
 	root.prepareScreen()
 	root.prepareDraw(ctx)
 	root.draw(ctx)
-	height = realHeight(root.scr) + 1
+	height = realHeight(root.scr)
 	return height, nil
 }
 
 func realHeight(scr SCR) int {
 	height := 0
-	for ; height < scr.vHeight-1; height++ {
+	for ; height < scr.vHeight-scr.statusLineHeight; height++ {
 		if !scr.lines[scr.numbers[height].number].valid {
 			break
 		}
@@ -1290,12 +1413,23 @@ func (scr SCR) lineNumber(y int) LineNumber {
 	if len(scr.numbers) == 0 {
 		return LineNumber{}
 	}
-	if y >= 0 && y <= len(scr.numbers) {
+	if y >= 0 && y < len(scr.numbers) {
 		return scr.numbers[y]
 	}
 	return scr.numbers[0]
 }
 
+// lineY returns the screen y position for a given LineNumber.
+// If not found, returns -1.
+func (scr SCR) lineY(ln LineNumber) int {
+	for y, num := range scr.numbers {
+		if num == ln {
+			return y
+		}
+	}
+	return -1
+}
+
 // debugNumOfChunk outputs the number of chunks.
 func (root *Root) debugNumOfChunk() {
 	if !root.Config.Debug {
