@@ -21,6 +21,19 @@ func Test_escapeSequence_convert(t *testing.T) {
 		want      bool
 		wantState int
 	}{
+		{
+			name: "test-blank",
+			fields: fields{
+				state: ansiText,
+			},
+			args: args{
+				st: &parseState{
+					str: "",
+				},
+			},
+			want:      false,
+			wantState: ansiText,
+		},
 		{
 			name: "test-escapeSequence",
 			fields: fields{
@@ -28,7 +41,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: 0x1b,
+					str: "\x1b",
 				},
 			},
 			want:      true,
@@ -41,7 +54,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: 'P',
+					str: "P",
 				},
 			},
 			want:      true,
@@ -54,7 +67,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: 0x1b,
+					str: "\x1b",
 				},
 			},
 			want:      true,
@@ -67,7 +80,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: '(',
+					str: "(",
 				},
 			},
 			want:      true,
@@ -80,7 +93,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: '@',
+					str: "@",
 				},
 			},
 			want:      true,
@@ -93,11 +106,24 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: 'a',
+					str: "a",
 				},
 			},
 			want:      true,
-			wantState: ansiEscape,
+			wantState: otherSequence,
+		},
+		{
+			name: "test-OtherSequence3",
+			fields: fields{
+				state: otherSequence,
+			},
+			args: args{
+				st: &parseState{
+					str: "B",
+				},
+			},
+			want:      true,
+			wantState: ansiText,
 		},
 		{
 			name: "test-ControlSequence",
@@ -106,7 +132,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: 'm',
+					str: "m",
 				},
 			},
 			want:      true,
@@ -119,7 +145,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: 'A',
+					str: "A",
 				},
 			},
 			want:      true,
@@ -132,7 +158,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: '?',
+					str: "?",
 				},
 			},
 			want:      true,
@@ -145,7 +171,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: '@',
+					str: "@",
 				},
 			},
 			want:      true,
@@ -158,7 +184,7 @@ func Test_escapeSequence_convert(t *testing.T) {
 			},
 			args: args{
 				st: &parseState{
-					mainc: 0x07,
+					str: "\x07",
 				},
 			},
 			want:      true,
@@ -244,6 +270,33 @@ func Test_sgrStyle(t *testing.T) {
 			want:    tcell.StyleDefault.Dim(true).Italic(true).Underline(true).Blink(true).Reverse(true).StrikeThrough(true),
 			wantErr: false,
 		},
+		{
+			name: "UnderLine double",
+			args: args{
+				style:        tcell.StyleDefault,
+				csiParameter: "4:2",
+			},
+			want:    tcell.StyleDefault.Underline(true).Underline(underLineStyle("2")),
+			wantErr: false,
+		},
+		{
+			name: "UnderLine double2",
+			args: args{
+				style:        tcell.StyleDefault,
+				csiParameter: "21",
+			},
+			want:    tcell.StyleDefault.Underline(true).Underline(underLineStyle("2")),
+			wantErr: false,
+		},
+		{
+			name: "UnderLine color",
+			args: args{
+				style:        tcell.StyleDefault,
+				csiParameter: "4;58;2;255;0;0",
+			},
+			want:    tcell.StyleDefault.Underline(true).Underline(tcell.GetColor("#FF0000")),
+			wantErr: false,
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -331,7 +384,7 @@ func Test_parseSGR(t *testing.T) {
 			wantErr: false,
 		},
 		{
-			name: "test-forground2",
+			name: "test-foreground2",
 			args: args{
 				params: "038;05;02",
 			},
@@ -340,7 +393,7 @@ func Test_parseSGR(t *testing.T) {
 			},
 		},
 		{
-			name: "test-forground216",
+			name: "test-foreground216",
 			args: args{
 				params: "38;5;216",
 			},
@@ -350,7 +403,7 @@ func Test_parseSGR(t *testing.T) {
 			wantErr: false,
 		},
 		{
-			name: "test-forground216_Underline",
+			name: "test-foreground216_Underline",
 			args: args{
 				params: "38;5;216;4",
 			},
@@ -365,6 +418,7 @@ func Test_parseSGR(t *testing.T) {
 				params: "38;5;216;0;4",
 			},
 			want: OVStyle{
+				Reset:     true,
 				Underline: true,
 			},
 		},
@@ -471,6 +525,13 @@ func Test_parseSGR2(t *testing.T) {
 			},
 			want: OVStyle{},
 		},
+		{
+			name: "test-rgb-invalid2",
+			args: args{
+				params: "4;48:2:255:0:-",
+			},
+			want: OVStyle{},
+		},
 		{
 			name: "test-rgb-over",
 			args: args{
@@ -490,6 +551,76 @@ func Test_parseSGR2(t *testing.T) {
 	}
 }
 
+func Test_parseSGR3(t *testing.T) {
+	type args struct {
+		params string
+	}
+	tests := []struct {
+		name string
+		args args
+		want OVStyle
+	}{
+		{
+			name: "test-not-supported",
+			args: args{
+				params: "99;a:4",
+			},
+			want: OVStyle{},
+		},
+		{
+			name: "test-overline-on",
+			args: args{
+				params: "53",
+			},
+			want: OVStyle{
+				OverLine: true,
+			},
+		},
+		{
+			name: "test-overline-off",
+			args: args{
+				params: "55",
+			},
+			want: OVStyle{
+				OverLine:   false,
+				UnOverLine: true,
+			},
+		},
+		{
+			name: "test-underline-color-error",
+			args: args{
+				params: "58;a",
+			},
+			want: OVStyle{},
+		},
+		{
+			name: "test-underline-color-default",
+			args: args{
+				params: "59",
+			},
+			want: OVStyle{
+				UnderlineColor: "default",
+			},
+		},
+		{
+			name: "test-vertical-line-on",
+			args: args{
+				params: "74",
+			},
+			want: OVStyle{
+				VerticalAlignType: 1,
+			},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			if got := parseSGR(tt.args.params); !reflect.DeepEqual(got, tt.want) {
+				t.Errorf("parseSGR() = %#v, want %#v", got, tt.want)
+			}
+		})
+	}
+}
+
 func Test_colorName(t *testing.T) {
 	type args struct {
 		colorNumber int
