@@ -175,6 +175,10 @@ type Document struct {
 	reopenable bool
 	// nonMatch indicates if non-matching lines are searched.
 	nonMatch bool
+	// pauseFollow indicates if follow mode is paused.
+	pauseFollow bool
+	// pauseFollowNum is the line number where follow mode was paused.
+	pauseLastNum int
 	// General is the General settings.
 	General General
 }
