@@ -13,8 +13,8 @@ func getContents(t *testing.T, root *Root, y int, width int) string {
 	t.Helper()
 	var buf strings.Builder
 	for x := range width {
-		r, _, _, _ := root.Screen.GetContent(x, y)
-		buf.WriteRune(r)
+		s, _, _ := root.Screen.Get(x, y)
+		buf.WriteString(s)
 	}
 	return buf.String()
 }
@@ -380,7 +380,7 @@ func TestRoot_sectionLineHighlight(t *testing.T) {
 		name      string
 		fields    fields
 		args      args
-		wantStr   rune
+		wantStr   string
 		wantStyle bool
 	}{
 		{
@@ -393,7 +393,7 @@ func TestRoot_sectionLineHighlight(t *testing.T) {
 			args: args{
 				y: 2,
 			},
-			wantStr:   '#',
+			wantStr:   "#",
 			wantStyle: true,
 		},
 		{
@@ -406,7 +406,7 @@ func TestRoot_sectionLineHighlight(t *testing.T) {
 			args: args{
 				y: 3,
 			},
-			wantStr:   '2',
+			wantStr:   "2",
 			wantStyle: false,
 		},
 		{
@@ -419,7 +419,7 @@ func TestRoot_sectionLineHighlight(t *testing.T) {
 			args: args{
 				y: 20,
 			},
-			wantStr:   '~',
+			wantStr:   "~",
 			wantStyle: false,
 		},
 	}
@@ -439,7 +439,7 @@ func TestRoot_sectionLineHighlight(t *testing.T) {
 				t.Fatalf("line is not found %d", tt.args.y)
 			}
 			root.sectionLineHighlight(tt.args.y, line)
-			p, _, style, _ := root.Screen.GetContent(0, tt.args.y)
+			p, style, _ := root.Screen.Get(0, tt.args.y)
 			if p != tt.wantStr {
 				t.Errorf("Root.sectionLineHighlight() = %v, want %v", p, tt.wantStr)
 			}
@@ -485,9 +485,9 @@ func TestRoot_drawVerticalHeader(t *testing.T) {
 				y: 0,
 				lineC: LineC{
 					lc: []content{
-						{mainc: 'A', style: tcell.StyleDefault},
-						{mainc: 'B', style: tcell.StyleDefault},
-						{mainc: 'C', style: tcell.StyleDefault},
+						{str: "A", style: tcell.StyleDefault},
+						{str: "B", style: tcell.StyleDefault},
+						{str: "C", style: tcell.StyleDefault},
 					},
 					valid: true,
 				},
@@ -504,9 +504,9 @@ func TestRoot_drawVerticalHeader(t *testing.T) {
 				y: 0,
 				lineC: LineC{
 					lc: []content{
-						{mainc: 'A', style: tcell.StyleDefault},
-						{mainc: 'B', style: tcell.StyleDefault},
-						{mainc: 'C', style: tcell.StyleDefault},
+						{str: "A", style: tcell.StyleDefault},
+						{str: "B", style: tcell.StyleDefault},
+						{str: "C", style: tcell.StyleDefault},
 					},
 					columnRanges: []columnRange{
 						{start: 0, end: 1},
@@ -527,9 +527,9 @@ func TestRoot_drawVerticalHeader(t *testing.T) {
 				y: 0,
 				lineC: LineC{
 					lc: []content{
-						{mainc: 'A', style: tcell.StyleDefault},
-						{mainc: 'B', style: tcell.StyleDefault},
-						{mainc: 'C', style: tcell.StyleDefault},
+						{str: "A", style: tcell.StyleDefault},
+						{str: "B", style: tcell.StyleDefault},
+						{str: "C", style: tcell.StyleDefault},
 					},
 					valid: true,
 				},
@@ -621,75 +621,74 @@ func TestRoot_calculateVerticalHeader(t *testing.T) {
 func TestNeedsDisplaySync(t *testing.T) {
 	tests := []struct {
 		name     string
-		mainc    rune
-		combc    []rune
+		str      string
 		expected bool
 	}{
 		// No combining characters, not emoji
-		{"ASCII letter", 'a', nil, false},
-		{"ASCII digit", '5', nil, false},
-		{"ASCII space", ' ', nil, false},
+		{"ASCII letter", "a", false},
+		{"ASCII digit", "5", false},
+		{"ASCII space", " ", false},
 
 		// CJK characters (wide, but not ambiguous)
-		{"CJK character", 'あ', nil, false},
+		{"CJK character", "あ", false},
 
 		// Latin-1 characters (some are ambiguous!)
-		{"Latin à (ambiguous)", 'à', nil, true},
-		{"Latin á (ambiguous)", 'á', nil, true},
-		{"Latin â (not ambiguous)", 'â', nil, false},
-		{"Latin é (ambiguous)", 'é', nil, true},
-		{"Latin ë (not ambiguous)", 'ë', nil, false},
+		{"Latin à (ambiguous)", "à", true},
+		{"Latin á (ambiguous)", "á", true},
+		{"Latin â (not ambiguous)", "â", false},
+		{"Latin é (ambiguous)", "é", true},
+		{"Latin ë (not ambiguous)", "ë", false},
 
 		// Traditional ambiguous width characters
-		{"Section sign", '§', nil, true},
-		{"Degree sign", '°', nil, true},
-		{"Plus-minus", '±', nil, true},
+		{"Section sign", "§", true},
+		{"Degree sign", "°", true},
+		{"Plus-minus", "±", true},
 
 		// Box drawing characters
-		{"Box horizontal", '─', nil, true},
-		{"Box vertical", '│', nil, true},
+		{"Box horizontal", "─", true},
+		{"Box vertical", "│", true},
 
 		// Mathematical symbols (ambiguous)
-		{"Mathematical symbol ∀", '∀', nil, true},
-		{"Mathematical symbol ∃", '∃', nil, true},
+		{"Mathematical symbol ∀", "∀", true},
+		{"Mathematical symbol ∃", "∃", true},
 
 		// Arrow symbols (ambiguous)
-		{"Arrow →", '→', nil, true},
-		{"Arrow ←", '←', nil, true},
-		{"Arrow ↑", '↑', nil, true},
-		{"Arrow ↓", '↓', nil, true},
+		{"Arrow →", "→", true},
+		{"Arrow ←", "←", true},
+		{"Arrow ↑", "↑", true},
+		{"Arrow ↓", "↓", true},
 
 		// With combining characters (always true)
-		{"ASCII with combining", 'a', []rune{0x0300}, true},
-		{"Emoji with ZWJ", '👨', []rune{0x200D}, true},
-		{"Emoji with variation selector", '⚕', []rune{0xFE0F}, true},
-		{"Emoji with skin tone", '👋', []rune{0x1F3FB}, true},
+		{"ASCII with combining", "a\u0300", true},
+		{"Emoji with ZWJ", "👨\u200D", true},
+		{"Emoji with variation selector", "⚕\uFE0F", true},
+		{"Emoji with skin tone", "👋\U0001F3FB", true},
 
 		// Emoji range test (no combining characters)
-		{"Regional indicator", '🇺', nil, true}, // U+1F1FA
-		{"Another regional", '🇲', nil, true},   // U+1F1F2
-		{"Fire emoji", '🔥', nil, true},         // U+1F525
-		{"Rocket emoji", '🚀', nil, true},       // U+1F680
-		{"Grinning face", '😀', nil, true},      // U+1F600
-		{"Thinking face", '🤔', nil, true},      // U+1F914
-		{"Rainbow", '🌈', nil, true},            // U+1F308
+		{"Regional indicator", "🇺", true}, // U+1F1FA
+		{"Another regional", "🇲", true},   // U+1F1F2
+		{"Fire emoji", "🔥", true},         // U+1F525
+		{"Rocket emoji", "🚀", true},       // U+1F680
+		{"Grinning face", "😀", true},      // U+1F600
+		{"Thinking face", "🤔", true},      // U+1F914
+		{"Rainbow", "🌈", true},            // U+1F308
 
 		// Outside emoji range
-		{"Before emoji range", 0x1F1DF, nil, false},
-		{"After emoji range", 0x1FA00, nil, false},
+		{"Before emoji range", string(rune(0x1F1DF)), false},
+		{"After emoji range", string(rune(0x1FA00)), false},
 
 		// Boundary value test
-		{"First regional", 0x1F1E0, nil, true},
-		{"Last in range", 0x1F9FF, nil, true},
-		{"Just after range", 0x1FA00, nil, false},
+		{"First regional", string(rune(0x1F1E0)), true},
+		{"Last in range", string(rune(0x1F9FF)), true},
+		{"Just after range", string(rune(0x1FA00)), false},
 	}
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			result := needsDisplaySync(tt.mainc, tt.combc)
+			result := needsDisplaySync(tt.str)
 			if result != tt.expected {
-				t.Errorf("needsDisplaySync(%c / U+%04X, %v) = %v, want %v",
-					tt.mainc, tt.mainc, tt.combc, result, tt.expected)
+				t.Errorf("needsDisplaySync(%q, ...) = %v, want %v",
+					tt.str, result, tt.expected)
 			}
 		})
 	}
@@ -698,36 +697,35 @@ func TestNeedsDisplaySync(t *testing.T) {
 func TestNeedsDisplaySyncComplexSequences(t *testing.T) {
 	tests := []struct {
 		name     string
-		mainc    rune
-		combc    []rune
+		str      string
 		expected bool
 	}{
 		// ZWJ sequences
-		{"ZWJ sequence start", '👨', []rune{0x200D, '⚕', 0xFE0F}, true},
-		{"With multiple combining", '👋', []rune{0x1F3FB, 0x200D, '♂', 0xFE0F}, true},
+		{"ZWJ sequence start", "👨\u200D⚕\uFE0F", true},
+		{"With multiple combining", "👋\U0001F3FB\u200D♂\uFE0F", true},
 
 		// Variation selectors
-		{"Variation selector 15", '⚕', []rune{0xFE0E}, true},
-		{"Variation selector 16", '⚕', []rune{0xFE0F}, true},
+		{"Variation selector 15", "⚕\uFE0E", true},
+		{"Variation selector 16", "⚕\uFE0F", true},
 
 		// Skin tone modifiers
-		{"Light skin tone", '👋', []rune{0x1F3FB}, true},
-		{"Medium-light skin", '👋', []rune{0x1F3FC}, true},
-		{"Medium skin", '👋', []rune{0x1F3FD}, true},
-		{"Medium-dark skin", '👋', []rune{0x1F3FE}, true},
-		{"Dark skin tone", '👋', []rune{0x1F3FF}, true},
+		{"Light skin tone", "👋\U0001F3FB", true},
+		{"Medium-light skin", "👋\U0001F3FC", true},
+		{"Medium skin", "👋\U0001F3FD", true},
+		{"Medium-dark skin", "👋\U0001F3FE", true},
+		{"Dark skin tone", "👋\U0001F3FF", true},
 
 		// Multiple combining characters
-		{"Multiple combiners", 'a', []rune{0x0300, 0x0301}, true},
-		{"Empty combining", 'a', []rune{}, false},
+		{"Multiple combiners", "a\u0300\u0301", true},
+		{"Empty combining", "a", false},
 	}
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			result := needsDisplaySync(tt.mainc, tt.combc)
+			result := needsDisplaySync(tt.str)
 			if result != tt.expected {
-				t.Errorf("needsDisplaySync(%c / U+%04X, %v) = %v, want %v",
-					tt.mainc, tt.mainc, tt.combc, result, tt.expected)
+				t.Errorf("needsDisplaySync(%q) = %v, want %v",
+					tt.str, result, tt.expected)
 			}
 		})
 	}
@@ -735,15 +733,15 @@ func TestNeedsDisplaySyncComplexSequences(t *testing.T) {
 
 func TestNeedsDisplaySyncPerformance(t *testing.T) {
 	// Performance test for ASCII characters (most frequent case)
-	asciiChars := []rune{
-		'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j',
-		'0', '1', '2', '3', '4', '5', '6', '7', '8', '9',
-		' ', '!', '@', '#', '$', '%', '^', '&', '*', '(',
+	asciiChars := []string{
+		"a", "b", "c", "d", "e", "f", "g", "h", "i", "j",
+		"0", "1", "2", "3", "4", "5", "6", "7", "8", "9",
+		" ", "!", "@", "#", "$", "%", "^", "&", "*", "(",
 	}
 
-	for _, r := range asciiChars {
-		if needsDisplaySync(r, nil) {
-			t.Errorf("ASCII character %c should not need display sync", r)
+	for _, s := range asciiChars {
+		if needsDisplaySync(s) {
+			t.Errorf("ASCII character %q should not need display sync", s)
 		}
 	}
 }
