@@ -1,12 +1,16 @@
 package oviewer
 
-import "github.com/gdamore/tcell/v2"
+import (
+	"context"
 
-// setGoLineMode sets the inputMode to Goline.
-func (root *Root) setGoLineMode() {
+	"github.com/gdamore/tcell/v2"
+)
+
+// inputGoLine sets the inputMode to Goline.
+func (root *Root) inputGoLine(context.Context) {
 	input := root.input
 	input.reset()
-	input.Event = newGotoEvent(input.GoCandidate)
+	input.Event = newGotoEvent(input.Candidate[Goline])
 }
 
 // eventGoto represents the goto input mode.
