@@ -7,7 +7,7 @@ import (
 	"github.com/gdamore/tcell/v2"
 )
 
-func candidateHelpter() *candidate {
+func candidateHelper() *candidate {
 	return &candidate{
 		list: []string{"a", "b", "c"},
 	}
@@ -236,7 +236,7 @@ func TestInput_previous(t *testing.T) {
 		{
 			name: "testPrevious",
 			fields: fields{
-				Event:   newSearchEvent(candidateHelpter(), forward),
+				Event:   newSearchEvent(candidateHelper(), forward),
 				value:   "test",
 				cursorX: 4,
 			},
@@ -273,7 +273,7 @@ func TestInput_next(t *testing.T) {
 		{
 			name: "testNext",
 			fields: fields{
-				Event:   newSearchEvent(candidateHelpter(), forward),
+				Event:   newSearchEvent(candidateHelper(), forward),
 				value:   "test",
 				cursorX: 4,
 			},
@@ -298,23 +298,23 @@ func TestInput_next(t *testing.T) {
 func TestRoot_inputPrompt(t *testing.T) {
 	root := rootHelper(t)
 	ctx := context.Background()
-	root.setDelimiterMode(ctx)
+	root.inputDelimiter(ctx)
 	if root.inputPrompt() != "Delimiter:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Delimiter:")
 	}
-	root.setHeaderMode(ctx)
+	root.inputHeader(ctx)
 	if root.inputPrompt() != "Header length:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Header length:")
 	}
-	root.setSkipLinesMode(ctx)
+	root.inputSkipLines(ctx)
 	if root.inputPrompt() != "Skip lines:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Skip lines:")
 	}
-	root.setGoLineMode(ctx)
+	root.inputGoLine(ctx)
 	if root.inputPrompt() != "Goto line:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Goto line:")
 	}
-	root.setMultiColorMode(ctx)
+	root.inputMultiColor(ctx)
 	if root.inputPrompt() != "Multi color:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Multi color:")
 	}
@@ -322,115 +322,115 @@ func TestRoot_inputPrompt(t *testing.T) {
 	if root.inputPrompt() != "" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "")
 	}
-	root.setForwardSearchMode(ctx)
+	root.inputForwardSearch(ctx)
 	if root.inputPrompt() != "/" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "/")
 	}
-	root.setBackSearchMode(ctx)
+	root.inputBackSearch(ctx)
 	if root.inputPrompt() != "?" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "?")
 	}
-	root.setSearchFilterMode(ctx)
+	root.inputSearchFilter(ctx)
 	if root.inputPrompt() != "&" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "&")
 	}
-	root.setJumpTargetMode(ctx)
-	if root.inputPrompt() != "Jump Target line:" {
-		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Jump Target line:")
+	root.inputJumpTarget(ctx)
+	if root.inputPrompt() != "Jump target line:" {
+		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Jump target line:")
 	}
-	root.setSaveBufferMode(ctx)
+	root.inputSaveBuffer(ctx)
 	if root.inputPrompt() != "(Save)file:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "(Save)file:")
 	}
-	root.setViewInputMode(ctx)
+	root.inputViewMode(ctx)
 	if root.inputPrompt() != "Mode:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Mode:")
 	}
-	root.setWatchIntervalMode(ctx)
+	root.inputWatchInterval(ctx)
 	if root.inputPrompt() != "Watch interval:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Watch interval:")
 	}
-	root.setWriteBAMode(ctx)
+	root.inputWriteBA(ctx)
 	if root.inputPrompt() != "WriteAndQuit Before:After:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "WriteAndQuit Before:After:")
 	}
-	root.setTabWidthMode(ctx)
+	root.inputTabWidth(ctx)
 	if root.inputPrompt() != "TAB width:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "TAB width:")
 	}
-	root.setSectionDelimiterMode(ctx)
+	root.inputSectionDelimiter(ctx)
 	if root.inputPrompt() != "Section delimiter:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Section delimiter:")
 	}
-	root.setSectionStartMode(ctx)
+	root.inputSectionStart(ctx)
 	if root.inputPrompt() != "Section start:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Section start:")
 	}
-	root.setSectionNumMode(ctx)
+	root.inputSectionNum(ctx)
 	if root.inputPrompt() != "Section Num:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Section Num:")
 	}
-	root.setSectionStartMode(ctx)
+	root.inputSectionStart(ctx)
 	if root.inputPrompt() != "Section start:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Section start:")
 	}
-	root.setConvertType(ctx)
+	root.inputConvert(ctx)
 	if root.inputPrompt() != "Convert:" {
 		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Convert:")
 	}
-	root.setVerticalHeaderMode(ctx)
-	if root.inputPrompt() != "Vertical Header length:" {
-		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Vertical Header length:")
+	root.inputVerticalHeader(ctx)
+	if root.inputPrompt() != "Vertical header length:" {
+		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Vertical header length:")
 	}
-	root.setHeaderColumnMode(ctx)
-	if root.inputPrompt() != "Vertical Header Column length:" {
-		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Vertical Header Column length:")
+	root.inputHeaderColumn(ctx)
+	if root.inputPrompt() != "Header column:" {
+		t.Errorf("Root.inputMode() = %v, want %v", root.inputPrompt(), "Header column:")
 	}
 }
 
 func TestRoot_inputState(t *testing.T) {
 	root := rootHelper(t)
 	ctx := context.Background()
-	root.setForwardSearchMode(ctx)
+	root.inputForwardSearch(ctx)
 	root.setSearcher("test", false)
-	root.inputCaseSensitive(ctx)
+	root.toggleCaseSensitive(ctx)
 	if root.searchOpt != "(Aa)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "(Aa)")
 	}
-	root.inputSmartCaseSensitive(ctx)
+	root.toggleSmartCaseSensitive(ctx)
 	if root.searchOpt != "(S)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "(S)")
 	}
-	root.inputIncSearch(ctx)
+	root.toggleIncSearch(ctx)
 	if root.searchOpt != "(I)(S)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "(I)(S)")
 	}
-	root.inputRegexpSearch(ctx)
+	root.toggleRegexpSearch(ctx)
 	if root.searchOpt != "(R)(I)(S)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "(R)(I)(S)")
 	}
 	if root.searchOpt != "(R)(I)(S)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "(R)(I)(S)")
 	}
-	root.inputNonMatch(ctx)
-	root.setBackSearchMode(ctx)
+	root.toggleNonMatch(ctx)
+	root.inputBackSearch(ctx)
 	if root.searchOpt != "(R)(I)(S)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "(R)(I)(S)")
 	}
-	root.setSearchFilterMode(ctx)
-	root.inputNonMatch(ctx)
+	root.inputSearchFilter(ctx)
+	root.toggleNonMatch(ctx)
 	if root.searchOpt != "Non-match(R)(S)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "Non-match(R)(S)")
 	}
-	root.inputPrevious(ctx)
+	root.candidatePrevious(ctx)
 	if root.searchOpt != "Non-match(R)(S)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "Non-match(R)(S)")
 	}
-	root.inputNext(ctx)
+	root.candidateNext(ctx)
 	if root.searchOpt != "Non-match(R)(S)" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "Non-match(R)(S)")
 	}
-	root.setHeaderMode(ctx)
+	root.inputHeader(ctx)
 	root.setPromptOpt()
 	if root.searchOpt != "" {
 		t.Errorf("Root.inputState() = %v, want %v", root.searchOpt, "")
@@ -810,3 +810,216 @@ func TestRoot_inputDown(t *testing.T) {
 		})
 	}
 }
+
+func Test_stringWidth(t *testing.T) {
+	tests := []struct {
+		name string
+		str  string
+		want int
+	}{
+		{
+			name: "empty string",
+			str:  "",
+			want: 0,
+		},
+		{
+			name: "ascii string",
+			str:  "test",
+			want: 4,
+		},
+		{
+			name: "single tab",
+			str:  "\t",
+			want: 2,
+		},
+		{
+			name: "multiple tabs",
+			str:  "\t\t\t",
+			want: 6,
+		},
+		{
+			name: "tab with text",
+			str:  "test\tvalue",
+			want: 11,
+		},
+		{
+			name: "wide characters",
+			str:  "テスト",
+			want: 6,
+		},
+		{
+			name: "mixed ascii and wide",
+			str:  "test テスト",
+			want: 11,
+		},
+		{
+			name: "tab with wide characters",
+			str:  "\tテスト",
+			want: 8,
+		},
+		{
+			name: "emoji",
+			str:  "👍",
+			want: 2,
+		},
+		{
+			name: "mixed content",
+			str:  "a\tb👍c",
+			want: 7,
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			if got := stringWidth(tt.str); got != tt.want {
+				t.Errorf("stringWidth() = %v, want %v", got, tt.want)
+			}
+		})
+	}
+}
+func Test_splitAtWidth(t *testing.T) {
+	tests := []struct {
+		name        string
+		s           string
+		targetWidth int
+		wantLeft    string
+		wantRight   string
+	}{
+		{
+			name:        "empty string",
+			s:           "",
+			targetWidth: 5,
+			wantLeft:    "",
+			wantRight:   "",
+		},
+		{
+			name:        "zero width",
+			s:           "test",
+			targetWidth: 0,
+			wantLeft:    "",
+			wantRight:   "test",
+		},
+		{
+			name:        "split ascii at middle",
+			s:           "test",
+			targetWidth: 2,
+			wantLeft:    "te",
+			wantRight:   "st",
+		},
+		{
+			name:        "split ascii at end",
+			s:           "test",
+			targetWidth: 4,
+			wantLeft:    "test",
+			wantRight:   "",
+		},
+		{
+			name:        "split beyond length",
+			s:           "test",
+			targetWidth: 10,
+			wantLeft:    "test",
+			wantRight:   "",
+		},
+		{
+			name:        "split with single tab",
+			s:           "\t",
+			targetWidth: 1,
+			wantLeft:    "",
+			wantRight:   "\t",
+		},
+		{
+			name:        "split with tab width 2",
+			s:           "\t",
+			targetWidth: 2,
+			wantLeft:    "\t",
+			wantRight:   "",
+		},
+		{
+			name:        "split with tab and text before",
+			s:           "ab\tcd",
+			targetWidth: 3,
+			wantLeft:    "ab",
+			wantRight:   "\tcd",
+		},
+		{
+			name:        "split with tab and text after width",
+			s:           "ab\tcd",
+			targetWidth: 4,
+			wantLeft:    "ab\t",
+			wantRight:   "cd",
+		},
+		{
+			name:        "split multiple tabs",
+			s:           "\t\t\t",
+			targetWidth: 4,
+			wantLeft:    "\t\t",
+			wantRight:   "\t",
+		},
+		{
+			name:        "split wide characters",
+			s:           "テスト",
+			targetWidth: 4,
+			wantLeft:    "テス",
+			wantRight:   "ト",
+		},
+		{
+			name:        "split wide characters exact",
+			s:           "テスト",
+			targetWidth: 6,
+			wantLeft:    "テスト",
+			wantRight:   "",
+		},
+		{
+			name:        "split mixed ascii and wide",
+			s:           "testテスト",
+			targetWidth: 8,
+			wantLeft:    "testテス",
+			wantRight:   "ト",
+		},
+		{
+			name:        "split with emoji",
+			s:           "a👍b",
+			targetWidth: 2,
+			wantLeft:    "a",
+			wantRight:   "👍b",
+		},
+		{
+			name:        "split with emoji at boundary",
+			s:           "a👍b",
+			targetWidth: 3,
+			wantLeft:    "a👍",
+			wantRight:   "b",
+		},
+		{
+			name:        "split complex mixed content",
+			s:           "a\tテスト👍",
+			targetWidth: 5,
+			wantLeft:    "a\tテ",
+			wantRight:   "スト👍",
+		},
+		{
+			name:        "split at tab boundary",
+			s:           "test\tvalue",
+			targetWidth: 6,
+			wantLeft:    "test\t",
+			wantRight:   "value",
+		},
+		{
+			name:        "split just before tab",
+			s:           "test\tvalue",
+			targetWidth: 5,
+			wantLeft:    "test",
+			wantRight:   "\tvalue",
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			gotLeft, gotRight := splitAtWidth(tt.s, tt.targetWidth)
+			if gotLeft != tt.wantLeft {
+				t.Errorf("splitAtWidth() gotLeft = %q, want %q", gotLeft, tt.wantLeft)
+			}
+			if gotRight != tt.wantRight {
+				t.Errorf("splitAtWidth() gotRight = %q, want %q", gotRight, tt.wantRight)
+			}
+		})
+	}
+}
