@@ -263,9 +263,9 @@ func (root *Root) handleSelectActive(ctx context.Context, ev *tcell.EventMouse,
 
 // adjustPositionForWideChar adjusts the position if a wide character is clicked.
 func (root *Root) adjustPositionForWideChar(x, y int) (int, int) {
-	p, _, _, _ := root.Screen.GetContent(x, y)
-	if p == ' ' && x > 0 {
-		_, _, _, w := root.Screen.GetContent(x-1, y) // Adjust for clicking the second half of a wide character
+	p, _, _ := root.Screen.Get(x, y)
+	if p == " " && x > 0 {
+		_, _, w := root.Screen.Get(x-1, y) // Adjust for clicking the second half of a wide character
 		if w == 2 {
 			x--
 		}
@@ -443,14 +443,14 @@ func getCharTypeAt(line LineC, contentX int) int {
 		return charTypeWhitespace // Out of bounds treated as whitespace
 	}
 	content := line.lc[contentX]
-	char := content.mainc
+	char := firstRune(content.str)
 	width := content.width
 	if width == 0 && char == 0 {
 		if contentX == 0 {
 			return charTypeOther
 		}
 		// If width is 0, check the previous character.
-		char = line.lc[contentX-1].mainc
+		char = firstRune(line.lc[contentX-1].str)
 	}
 	if char == ' ' || char == '\t' {
 		return charTypeWhitespace
